@@ -51,6 +51,12 @@ class Extract:
             return
 
         self.regions = pd.read_csv(self.bed, sep='\t', header=None)
+
+        # only keep Y chrom regions
+        self.regions = self.regions[self.regions[0].isin(['Y', 'chrY'])]
+        if len(self.regions) == 0:
+            print('There are no Y chromosome regions. Cannot determine if there is a sex mismatch.')
+
         self.regions.columns = range(self.regions.shape[1])
 
     def _extract_regions(self, sample):
@@ -81,9 +87,9 @@ class Extract:
                 'end': end,
                 'count': count})
 
-        region_counts = pd.DataFrame(region_counts)
-
-        sample.region_counts = region_counts
+        if len(region_counts) > 0:
+            region_counts = pd.DataFrame(region_counts)
+            sample.region_counts = region_counts
 
         return sample
 
@@ -318,8 +324,7 @@ class Extract:
                 sample.load_from_file()
                 continue
 
-            # samples_to_extract.append(sample)
-            self._extraction_job(sample)
+            samples_to_extract.append(sample)
 
         # if any samples need to be extracted, then do so
         # (using multiprocessing)
